use openapiv3::Schema;
use proc_macro2::TokenStream;

pub mod client;
pub mod model;
pub mod util;
pub mod format;
